@@ -17,7 +17,6 @@ from netaddr import IPAddress
 
 from oslo_log import log as logging
 from tempest_lib.common.utils import data_utils
-from tempest_lib import decorators
 from tempest_lib import exceptions
 
 from neutron_lbaas.tests.tempest.lib import config
@@ -229,7 +228,6 @@ class LoadBalancersTestJSON(base.BaseTestCase):
                           wait=False,
                           tenant_id="&^%123")
 
-    @decorators.skip_because(bug="1434717")
     @test.attr(type='negative')
     def test_create_load_balancer_invalid_name(self):
         """Test create load balancer with an invalid name"""
@@ -240,7 +238,6 @@ class LoadBalancersTestJSON(base.BaseTestCase):
                           vip_subnet_id=self.subnet['id'],
                           name='n' * 256)
 
-    @decorators.skip_because(bug="1434717")
     @test.attr(type='negative')
     def test_create_load_balancer_invalid_description(self):
         """Test create load balancer with an invalid description"""
@@ -308,7 +305,6 @@ class LoadBalancersTestJSON(base.BaseTestCase):
             self.load_balancer_id)
         self.assertEqual(load_balancer.get('name'), "")
 
-    @decorators.skip_because(bug="1434717")
     @test.attr(type='negative')
     def test_update_load_balancer_invalid_name(self):
         """Test update load balancer with invalid name"""
@@ -330,7 +326,6 @@ class LoadBalancersTestJSON(base.BaseTestCase):
         load_balancer_new = load_balancer['name']
         self.assertEqual(load_balancer_initial, load_balancer_new)
 
-    @decorators.skip_because(bug="1434717")
     @test.attr(type='negative')
     def test_update_load_balancer_invalid_description(self):
         """Test update load balancer with invalid description"""
